---
name: 📘 Update documentation
about: Update the repo's documentation
title: DOCS
labels: documentation, good first issue, help wanted
assignees: ''

---
**What type of documentation needs to be updated?**
[ ] [API documentation](https://ibm.github.io/ibm-generative-ai/)
[ ] [Code of Conduct (CoC)](/CODE_OF_CONDUCT.md)
[ ] [Contribution Guide](/DEVELOPMENT.md)
[ ] [README file](/README.md)
[ ] [Project Team](/ACTIVE_PROJECT_TEAM.md)

**Is your documentation update related to a problem/software issue? Please describe.**
A clear and concise description of what the problem is. Ex. The API documentation must be updated [...] , The project team changed, we need to update the project team markdown file [...], etc.

**Additional context**
Add any other context or screenshots about how documentation must be updated.
